@@ -4,18 +4,21 @@
 #include "cad2d.h"
 
 /* $Format: "static const char* version = \"$ProjectVersion$\";"$ */
-static const char* version = "1.69";
+static const char* version = "1.71";
 
 /* $Format: "static const char* versdate = \"$ProjectDate$\";"$ */
-static const char* versdate = "Fri, 16 Mar 2012 10:21:38 -0400";
+static const char* versdate = "Tue Jan 30 16:04:07 EST 2018";
 
 static void setversline() {
   int j;
   SWRITE("QEPCAD Version B ");
   SWRITE(version);
   SWRITE(", ");
-  for(j = 5; j < 16; j++)
+  for(j = 4; j < 10; j++)
     CWRITE(versdate[j]);
+  while(versdate[++j] != '\0');
+  while(versdate[--j] != ' ');
+  SWRITE(versdate + j);
 }
 
 void PRINTCAD2DBANNER()
